@@ -10,12 +10,12 @@
 #include "identitymanager.h"
 #include "tagcache.h"
 
-#include <AkonadiCore/TagAttribute>
-#include <AkonadiCore/TagModifyJob>
+#include <Akonadi/TagAttribute>
+#include <Akonadi/TagModifyJob>
 
 #include <KMime/HeaderParsing>
 
-#include <KCodecs/KEmailAddress>
+#include <KEmailAddress>
 #include <KIdentityManagement/Identity>
 
 #include <KEMailSettings>
@@ -24,18 +24,16 @@ using namespace CalendarSupport;
 
 Q_GLOBAL_STATIC(KCalPrefs, globalPrefs)
 
-class Q_DECL_HIDDEN KCalPrefs::Private
+class CalendarSupport::KCalPrefsPrivate
 {
 public:
-    Private()
+    KCalPrefsPrivate()
         : mDefaultCalendarId(-1)
         , mDefaultCategoryColor(QColor(151, 235, 121))
     {
     }
 
-    ~Private()
-    {
-    }
+    ~KCalPrefsPrivate() = default;
 
     Akonadi::Collection::Id mDefaultCalendarId;
 
@@ -46,14 +44,11 @@ public:
 
 KCalPrefs::KCalPrefs()
     : KCalPrefsBase()
-    , d(new Private())
+    , d(new KCalPrefsPrivate())
 {
 }
 
-KCalPrefs::~KCalPrefs()
-{
-    delete d;
-}
+KCalPrefs::~KCalPrefs() = default;
 
 KCalPrefs *KCalPrefs::instance()
 {
@@ -162,7 +157,8 @@ QString KCalPrefs::fullName()
     // Quote the username as it might contain commas and other quotable chars.
     tusername = KEmailAddress::quoteNameIfNecessary(tusername);
 
-    QString tname, temail;
+    QString tname;
+    QString temail;
     // ignore the return value from extractEmailAddressAndName() because
     // it will always be false since tusername does not contain "@domain".
     KEmailAddress::extractEmailAddressAndName(tusername, temail, tname);
