@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CALENDARSUPPORT_INCIDENCEVIEWER_P_H
-#define CALENDARSUPPORT_INCIDENCEVIEWER_P_H
+#pragma once
 
 #include <QTextBrowser>
 
@@ -19,11 +18,14 @@ class TextBrowser : public QTextBrowser
 public:
     explicit TextBrowser(QWidget *parent = nullptr);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void setSource(const QUrl &name) override;
+#else
+    void doSetSource(const QUrl &name, QTextDocument::ResourceType type = QTextDocument::UnknownResource) override;
+#endif
 
 Q_SIGNALS:
     void attachmentUrlClicked(const QString &uri);
 };
 }
 
-#endif
