@@ -19,9 +19,7 @@ public:
     {
     }
 
-    ~CalPrintYear() override
-    {
-    }
+    ~CalPrintYear() override = default;
 
     Q_REQUIRED_RESULT QString groupName() const override
     {
@@ -55,8 +53,8 @@ public:
     void print(QPainter &p, int width, int height) override;
     void readSettingsWidget() override;
     void setSettingsWidget() override;
-    void loadConfig() override;
-    void saveConfig() override;
+    void doLoadConfig() override;
+    void doSaveConfig() override;
     void setDateRange(const QDate &from, const QDate &to) override;
 
 protected:
